@@ -119,14 +119,11 @@ class CreateWorkingCopyAction(BaseCreateWorkingCopyAction):
         # Retrieve the path of the pack in the user workspace
         pack = self._files['pack']
         working_dir = self.root().project().get_root(user_workspace=True)
-        path_in_workspace = os.path.join(
-            working_dir, pack.get_head_revision().get_path(relative=True),
-        )
+        pack_relpath = pack.get_head_revision().get_path(relative=True)
+        path_in_workspace = os.path.join(working_dir, pack_relpath)
 
         if not os.path.isdir(path_in_workspace):
-            path_on_site = os.path.join(
-                working_dir, self.root().project().get_root()
-            )
+            path_on_site = os.path.join(self.root().project().get_root(), pack_relpath)
             shutil.copytree(path_on_site, path_in_workspace)
 
 
