@@ -942,6 +942,29 @@ class ImportFiles(flow.Action):
                                                 'error': ''
                                             })
                                         continue
+                        
+                        if shot == 'Create':
+                            if file_name.endswith('_') or (file_name.endswith('_') and file_name[-3] == 't'):
+                                if preset.optional_init.get() == False:
+                                    find_entry = False
+                                    for s in incorrect['shots']:
+                                        if s['shot'] == dir_name:
+                                            find_entry = True
+                                            s['files'].append({
+                                                'name': file_fullname,
+                                                'error': 'init'
+                                            })
+                                            break
+                                    if find_entry == False:
+                                        incorrect['shots'].append({
+                                            'shot': dir_name,
+                                            'files': [{
+                                                'name': file_fullname,
+                                                'error': 'init'
+                                            }],
+                                            'error': ''
+                                        })
+                                    continue
 
                         #endregion
 
